#pragma once

#include <tesla.hpp>

class AlphaSymbol {
  private:
    s32 m_width;
    s32 m_height;
    const u8 *m_data;

  public:
    constexpr AlphaSymbol(size_t width, size_t height, const u8 *data)
        : m_width(width), m_height(height), m_data(data) {}

    void draw(s32 x, s32 y, tsl::gfx::Renderer *renderer, tsl::Color color) const {
        const u8 *ptr = this->m_data;
        const s32 x_offset = x - (m_width / 2);
        const s32 y_offset = y - (m_height / 2);
        for (s32 y1 = 0; y1 < m_height; y1++) {
            for (s32 x1 = 0; x1 < m_width; x1++) {
                color.a = static_cast<u16>(ptr[0] >> 4);
                renderer->setPixelBlendSrc(x_offset + x1, y_offset + y1, renderer->a(color));
                ptr++;
            }
        }
    }
};

namespace symbol {
    namespace repeat {
        namespace all {
            constexpr const size_t height = 30;
            constexpr const size_t width = 29;
            constexpr const unsigned char data[height * width] = {
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x74, 0xf0, 0x86, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //..................+@%........
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xda, 0xff, 0xff, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //..................@@@%.......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xde, 0xff, 0xff, 0xff, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //..................@@@@%......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xde, 0xff, 0xff, 0xff, 0xff, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, //..................@@@@@%.....
                0x00, 0x00, 0x00, 0x00, 0x00, 0x2e, 0x84, 0xc4, 0xde, 0xee, 0xee, 0xee, 0xee, 0xee, 0xee, 0xee, 0xee, 0xee, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0x92, 0x00, 0x00, 0x00, 0x00, //......%@@@@@@@@@@@@@@@@@%....
                0x00, 0x00, 0x00, 0x14, 0xa8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x36, 0x00, 0x00, 0x00, //....%@@@@@@@@@@@@@@@@@@@@....
                0x00, 0x00, 0x2c, 0xe0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x20, 0x00, 0x00, 0x00, //...@@@@@@@@@@@@@@@@@@@@@@....
                0x00, 0x1c, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xf8, 0xce, 0xb0, 0xae, 0xae, 0xae, 0xae, 0xae, 0xae, 0xae, 0xae, 0xf4, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x56, 0x00, 0x00, 0x00, 0x00, //..@@@@@@@%%%%%%%%%@@@@@@+....
                0x00, 0xbc, 0xff, 0xff, 0xff, 0xf4, 0x6c, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xde, 0xff, 0xff, 0xff, 0xfc, 0x56, 0x00, 0x30, 0xbc, 0x70, 0x00, //.%@@@@+...........@@@@@+..%+.
                0x44, 0xff, 0xff, 0xff, 0xf0, 0x24, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xde, 0xff, 0xff, 0xfc, 0x56, 0x00, 0x10, 0xe6, 0xff, 0xff, 0x34, //+@@@@.............@@@@+..@@@.
                0x9c, 0xff, 0xff, 0xff, 0x5c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xd2, 0xff, 0xfc, 0x56, 0x00, 0x00, 0x2e, 0xff, 0xff, 0xff, 0x90, //%@@@+.............@@@+...@@@%
                0xda, 0xff, 0xff, 0xea, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4a, 0xb6, 0x4c, 0x00, 0x00, 0x00, 0x02, 0xe6, 0xff, 0xff, 0xcc, //@@@@..............+%+....@@@@
                0xf2, 0xff, 0xff, 0xba, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xb2, 0xff, 0xff, 0xea, //@@@%.....................%@@@
                0xf2, 0xff, 0xff, 0xaa, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xb0, 0xff, 0xff, 0xf6, //@@@%.....................%@@@
                0xd6, 0xff, 0xff, 0xd4, 0x00, 0x00, 0x00, 0x00, 0x1e, 0x70, 0x1c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe2, 0xff, 0xff, 0xde, //@@@@.....+...............@@@@
                0xa8, 0xff, 0xff, 0xff, 0x20, 0x00, 0x00, 0x2a, 0xe8, 0xff, 0xc4, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x34, 0xff, 0xff, 0xff, 0xaa, //%@@@....@@@..............@@@%
                0x4c, 0xff, 0xff, 0xfa, 0x1c, 0x00, 0x2a, 0xe8, 0xff, 0xff, 0xde, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0a, 0xd8, 0xff, 0xff, 0xff, 0x5a, //+@@@...@@@@.............@@@@+
                0x04, 0xc8, 0xf8, 0x5c, 0x00, 0x2a, 0xe8, 0xff, 0xff, 0xff, 0xde, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0xcc, 0xff, 0xff, 0xff, 0xd6, 0x02, //.@@+..@@@@@............@@@@@.
                0x00, 0x00, 0x06, 0x00, 0x2a, 0xe8, 0xff, 0xff, 0xff, 0xff, 0xec, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x70, 0x8c, 0xbc, 0xfa, 0xff, 0xff, 0xff, 0xf8, 0x3a, 0x00, //.....@@@@@@+++++++++%%@@@@@..
                0x00, 0x00, 0x00, 0x10, 0xe8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x56, 0x00, 0x00, //....@@@@@@@@@@@@@@@@@@@@@@+..
                0x00, 0x00, 0x00, 0x50, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe2, 0x3a, 0x00, 0x00, 0x00, //...+@@@@@@@@@@@@@@@@@@@@@....
                0x00, 0x00, 0x00, 0x08, 0xc6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xc6, 0x6e, 0x08, 0x00, 0x00, 0x00, 0x00, //....@@@@@@@@@@@@@@@@@@@+.....
                0x00, 0x00, 0x00, 0x00, 0x0c, 0xc6, 0xff, 0xff, 0xff, 0xff, 0xe4, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x20, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.....@@@@@@..................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xc6, 0xff, 0xff, 0xff, 0xde, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......@@@@@..................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xc6, 0xff, 0xff, 0xde, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.......@@@@..................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xc4, 0xff, 0xa6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //........@@%..................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x36, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
            };
            constexpr const AlphaSymbol symbol(width, height, data);
        }

        namespace one {
            constexpr const size_t height = 30;
            constexpr const size_t width = 29;
            constexpr const unsigned char data[height * width] = {
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x74, 0xf0, 0x86, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //..................+@%........
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xda, 0xff, 0xff, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //..................@@@%.......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xde, 0xff, 0xff, 0xff, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //..................@@@@%......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xde, 0xff, 0xff, 0xff, 0xff, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, //..................@@@@@%.....
                0x00, 0x00, 0x00, 0x00, 0x00, 0x2e, 0x84, 0xc4, 0xde, 0xee, 0xee, 0xee, 0xee, 0xee, 0xee, 0xee, 0xee, 0xee, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0x92, 0x00, 0x00, 0x00, 0x00, //......%@@@@@@@@@@@@@@@@@%....
                0x00, 0x00, 0x00, 0x14, 0xa8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x36, 0x00, 0x00, 0x00, //....%@@@@@@@@@@@@@@@@@@@@....
                0x00, 0x00, 0x2c, 0xe0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x20, 0x00, 0x00, 0x00, //...@@@@@@@@@@@@@@@@@@@@@@....
                0x00, 0x1c, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xf8, 0xce, 0xb0, 0xae, 0xae, 0xae, 0xae, 0xae, 0xae, 0xae, 0xae, 0xf4, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x56, 0x00, 0x00, 0x00, 0x00, //..@@@@@@@%%%%%%%%%@@@@@@+....
                0x00, 0xbc, 0xff, 0xff, 0xff, 0xf4, 0x6c, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xde, 0xff, 0xff, 0xff, 0xfc, 0x56, 0x00, 0x30, 0xbc, 0x70, 0x00, //.%@@@@+...........@@@@@+..%+.
                0x44, 0xff, 0xff, 0xff, 0xf0, 0x24, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x7c, 0x22, 0x00, 0xde, 0xff, 0xff, 0xfc, 0x56, 0x00, 0x10, 0xe6, 0xff, 0xff, 0x34, //+@@@@..........+..@@@@+..@@@.
                0x9c, 0xff, 0xff, 0xff, 0x5c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6c, 0xff, 0xff, 0x7a, 0x00, 0xd2, 0xff, 0xfc, 0x56, 0x00, 0x00, 0x2e, 0xff, 0xff, 0xff, 0x90, //%@@@+........+@@+.@@@+...@@@%
                0xda, 0xff, 0xff, 0xea, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x12, 0xfc, 0xff, 0xff, 0x7a, 0x00, 0x4a, 0xb6, 0x4c, 0x00, 0x00, 0x00, 0x02, 0xe6, 0xff, 0xff, 0xcc, //@@@@.........@@@+.+%+....@@@@
                0xf2, 0xff, 0xff, 0xba, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x44, 0xb4, 0xff, 0x7a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xb2, 0xff, 0xff, 0xea, //@@@%.........+%@+........%@@@
                0xf2, 0xff, 0xff, 0xaa, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x9a, 0xff, 0x7a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xb0, 0xff, 0xff, 0xf6, //@@@%..........%@+........%@@@
                0xd6, 0xff, 0xff, 0xd4, 0x00, 0x00, 0x00, 0x00, 0x1e, 0x70, 0x1c, 0x00, 0x00, 0x08, 0xa2, 0xff, 0x84, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe2, 0xff, 0xff, 0xde, //@@@@.....+....%@%........@@@@
                0xa8, 0xff, 0xff, 0xff, 0x20, 0x00, 0x00, 0x2a, 0xe8, 0xff, 0xc4, 0x00, 0x14, 0xfa, 0xff, 0xff, 0xff, 0xec, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x34, 0xff, 0xff, 0xff, 0xaa, //%@@@....@@@..@@@@@.......@@@%
                0x4c, 0xff, 0xff, 0xfa, 0x1c, 0x00, 0x2a, 0xe8, 0xff, 0xff, 0xde, 0x00, 0x0a, 0xb2, 0xbe, 0xbe, 0xbe, 0xa4, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0a, 0xd8, 0xff, 0xff, 0xff, 0x5a, //+@@@...@@@@..%%%%%......@@@@+
                0x04, 0xc8, 0xf8, 0x5c, 0x00, 0x2a, 0xe8, 0xff, 0xff, 0xff, 0xde, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0xcc, 0xff, 0xff, 0xff, 0xd6, 0x02, //.@@+..@@@@@............@@@@@.
                0x00, 0x00, 0x06, 0x00, 0x2a, 0xe8, 0xff, 0xff, 0xff, 0xff, 0xec, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x70, 0x8c, 0xbc, 0xfa, 0xff, 0xff, 0xff, 0xf8, 0x3a, 0x00, //.....@@@@@@+++++++++%%@@@@@..
                0x00, 0x00, 0x00, 0x10, 0xe8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x56, 0x00, 0x00, //....@@@@@@@@@@@@@@@@@@@@@@+..
                0x00, 0x00, 0x00, 0x50, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe2, 0x3a, 0x00, 0x00, 0x00, //...+@@@@@@@@@@@@@@@@@@@@@....
                0x00, 0x00, 0x00, 0x08, 0xc6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xc6, 0x6e, 0x08, 0x00, 0x00, 0x00, 0x00, //....@@@@@@@@@@@@@@@@@@@+.....
                0x00, 0x00, 0x00, 0x00, 0x0c, 0xc6, 0xff, 0xff, 0xff, 0xff, 0xe4, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x20, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.....@@@@@@..................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xc6, 0xff, 0xff, 0xff, 0xde, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......@@@@@..................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xc6, 0xff, 0xff, 0xde, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.......@@@@..................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xc4, 0xff, 0xa6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //........@@%..................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x36, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
            };
            constexpr const AlphaSymbol symbol(width, height, data);
        }
    }

    namespace sd {
        constexpr const size_t height = 30;
        constexpr const size_t width = 23;
        constexpr const unsigned char data[height * width] = {
            0x00, 0x00, 0x00, 0x00, 0x00, 0x1e, 0xe0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x10, //......@@@@@@@@@@@@@@@@.
            0x00, 0x00, 0x00, 0x00, 0x1c, 0xdc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x82, //.....@@@@@@@@@@@@@@@@@%
            0x00, 0x00, 0x00, 0x1a, 0xda, 0xff, 0xe8, 0xbe, 0xbe, 0xde, 0xff, 0xd8, 0xbe, 0xbe, 0xf0, 0xff, 0xc8, 0xbe, 0xc0, 0xff, 0xff, 0xff, 0xb8, //....@@@%%@@@%%@@@%@@@@%
            0x00, 0x00, 0x18, 0xd8, 0xff, 0xff, 0xa2, 0x00, 0x00, 0x7e, 0xff, 0x62, 0x00, 0x00, 0xc2, 0xff, 0x22, 0x00, 0x02, 0xff, 0xff, 0xff, 0xc6, //...@@@%..+@+..@@...@@@@
            0x00, 0x14, 0xd4, 0xff, 0xff, 0xff, 0xa2, 0x00, 0x00, 0x7e, 0xff, 0x62, 0x00, 0x00, 0xc2, 0xff, 0x22, 0x00, 0x02, 0xff, 0xff, 0xff, 0xc6, //..@@@@%..+@+..@@...@@@@
            0x12, 0xd2, 0xff, 0xff, 0xff, 0xff, 0xa2, 0x00, 0x00, 0x7e, 0xff, 0x62, 0x00, 0x00, 0xc2, 0xff, 0x22, 0x00, 0x02, 0xff, 0xff, 0xff, 0xc6, //.@@@@@%..+@+..@@...@@@@
            0xce, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa2, 0x00, 0x00, 0x7e, 0xff, 0x62, 0x00, 0x00, 0xc2, 0xff, 0x22, 0x00, 0x02, 0xff, 0xff, 0xff, 0xc6, //@@@@@@%..+@+..@@...@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa2, 0x00, 0x00, 0x7e, 0xff, 0x62, 0x00, 0x00, 0xc2, 0xff, 0x22, 0x00, 0x02, 0xff, 0xff, 0xff, 0xc6, //@@@@@@%..+@+..@@...@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xcc, 0x6e, 0x6e, 0xb6, 0xff, 0xa8, 0x6e, 0x6e, 0xde, 0xff, 0x84, 0x6e, 0x72, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@++%@%++@@%++@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, //@@@@@@@@@@@@@@@@@@@@@@@
            0xe8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xae, //@@@@@@@@@@@@@@@@@@@@@@%
            0xa8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6c, //%@@@@@@@@@@@@@@@@@@@@@+
            0x1a, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc2, 0x02, //.@@@@@@@@@@@@@@@@@@@@@.
            0x00, 0x16, 0x98, 0xd0, 0xde, 0xde, 0xde, 0xde, 0xde, 0xde, 0xde, 0xde, 0xde, 0xde, 0xde, 0xde, 0xde, 0xde, 0xde, 0xc6, 0x7e, 0x06, 0x00, //..%@@@@@@@@@@@@@@@@@+..
        };
        constexpr const AlphaSymbol symbol(width, height, data);
    }

    namespace shuffle {
        constexpr const size_t height = 30;
        constexpr const size_t width = 29;
        constexpr const unsigned char data[height * width] = {
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x52, 0x6c, 0x06, 0x00, 0x00, 0x00, 0x00, //......................++.....
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0xff, 0xff, 0xb6, 0x06, 0x00, 0x00, 0x00, //......................@@%....
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3e, 0xff, 0xff, 0xff, 0xb6, 0x06, 0x00, 0x00, //......................@@@%...
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3e, 0xff, 0xff, 0xff, 0xff, 0xb6, 0x06, 0x00, //......................@@@@%..
            0xd2, 0xee, 0xee, 0xee, 0xee, 0xee, 0xee, 0x9e, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4e, 0xe6, 0xee, 0xee, 0xf2, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb6, 0x06, //@@@@@@@%.........+@@@@@@@@@%.
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x42, 0xf8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa0, //@@@@@@@@%.......+@@@@@@@@@@@%
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x8a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x36, 0xf2, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe2, //@@@@@@@@@%......@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x78, 0x00, 0x00, 0x00, 0x2a, 0xec, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x62, //@@@@@@@@@@+....@@@@@@@@@@@@@+
            0x7a, 0x96, 0x96, 0x96, 0x96, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0x34, 0x00, 0x20, 0xe4, 0xff, 0xff, 0xff, 0xff, 0xe4, 0x96, 0xb0, 0xff, 0xff, 0xff, 0xff, 0xff, 0x68, 0x00, //+%%%%%@@@@@...@@@@@@%%@@@@@+.
            0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xb4, 0xff, 0xff, 0xff, 0x8c, 0x00, 0x18, 0xdc, 0xff, 0xff, 0xff, 0xff, 0xec, 0x2a, 0x00, 0x3e, 0xff, 0xff, 0xff, 0xff, 0x68, 0x00, 0x00, //......%@@@%..@@@@@@...@@@@+..
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0xc2, 0xff, 0xa2, 0x00, 0x10, 0xd2, 0xff, 0xff, 0xff, 0xff, 0xf2, 0x34, 0x00, 0x00, 0x3e, 0xff, 0xff, 0xff, 0x68, 0x00, 0x00, 0x00, //.......@@%..@@@@@@....@@@+...
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0e, 0x8c, 0x04, 0x0a, 0xc6, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x42, 0x00, 0x00, 0x00, 0x14, 0xec, 0xfc, 0x68, 0x00, 0x00, 0x00, 0x00, //........%..@@@@@@+....@@+....
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0xba, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x4e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, //..........%@@@@@+............
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xac, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........%@@@@@+.............
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x9e, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, 0x00, 0x2e, 0x1e, 0x00, 0x00, 0x00, 0x08, 0xba, 0xd4, 0x36, 0x00, 0x00, 0x00, 0x00, //........%@@@@@+.......%@.....
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x8c, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x22, 0xe8, 0xd8, 0x14, 0x00, 0x00, 0x3a, 0xff, 0xff, 0xf0, 0x36, 0x00, 0x00, 0x00, //.......%@@@@@+..@@....@@@....
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7c, 0xff, 0xff, 0xff, 0xff, 0xff, 0x90, 0x00, 0x16, 0xdc, 0xff, 0xff, 0xce, 0x0e, 0x00, 0x3e, 0xff, 0xff, 0xff, 0xf0, 0x36, 0x00, 0x00, //......+@@@@@%..@@@@...@@@@...
            0x3e, 0x56, 0x56, 0x56, 0x56, 0x82, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa0, 0x00, 0x00, 0xc8, 0xff, 0xff, 0xff, 0xff, 0xc2, 0x56, 0x80, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x36, 0x00, //.++++%@@@@@%..@@@@@@+%@@@@@..
            0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xae, 0x02, 0x00, 0x00, 0x56, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x36, //@@@@@@@@@@%...+@@@@@@@@@@@@@.
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbc, 0x06, 0x00, 0x00, 0x00, 0x00, 0x64, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd2, //@@@@@@@@@%.....+@@@@@@@@@@@@@
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc8, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x74, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc2, //@@@@@@@@@.......+@@@@@@@@@@@@
            0xf4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd4, 0x12, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x84, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xde, 0x1e, //@@@@@@@@.........%@@@@@@@@@@.
            0x1c, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x2e, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x26, 0x2e, 0x2e, 0x62, 0xff, 0xff, 0xff, 0xff, 0xde, 0x1e, 0x00, //.....................+@@@@@..
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3e, 0xff, 0xff, 0xff, 0xde, 0x1e, 0x00, 0x00, //......................@@@@...
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x34, 0xff, 0xff, 0xde, 0x1e, 0x00, 0x00, 0x00, //......................@@@....
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x94, 0xb2, 0x1e, 0x00, 0x00, 0x00, 0x00, //......................%%.....
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.............................
        };
        constexpr const AlphaSymbol symbol(width, height, data);
    }

    namespace volume {
        namespace mute {
            constexpr const size_t height = 30;
            constexpr const size_t width = 15;
            constexpr const unsigned char data[height * width] = {
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //...............
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //...............
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //...............
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x84, 0x9c, 0x12, //............%%.
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xaa, 0xff, 0xff, 0x72, //...........%@@+
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xaa, 0xff, 0xff, 0xff, 0x7e, //..........%@@@+
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xaa, 0xff, 0xff, 0xff, 0xff, 0x7e, //.........%@@@@+
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xa8, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //........%@@@@@+
                0x08, 0x48, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0xaa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //.++++++%@@@@@@+
                0xc6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@+
                0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@+
                0x3c, 0x8c, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0xd6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //.%%%%%%@@@@@@@+
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0xd6, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //........@@@@@@+
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0xd6, 0xff, 0xff, 0xff, 0xff, 0x7e, //.........@@@@@+
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0xd6, 0xff, 0xff, 0xff, 0x7e, //..........@@@@+
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0xd6, 0xff, 0xff, 0x7a, //...........@@@+
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0xc8, 0xe0, 0x2c, //............@@.
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //...............
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //...............
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //...............
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //...............
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //...............
            };
            constexpr const AlphaSymbol symbol(width, height, data);
        }

        namespace low {
            constexpr const size_t height = 30;
            constexpr const size_t width = 22;
            constexpr const unsigned char data[height * width] = {
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x76, 0x8e, 0x0e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //............+%........
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x9c, 0xff, 0xff, 0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //...........%@@+.......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x9c, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //..........%@@@+.......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x9c, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........%@@@@+.......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x9a, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //........%@@@@@+.......
                0x02, 0x38, 0x3e, 0x3e, 0x3e, 0x3e, 0x3e, 0x9c, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.......%@@@@@@+.......
                0xba, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x0c, 0x3e, 0x0c, 0x00, 0x00, //%@@@@@@@@@@@@@+.......
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0xae, 0xff, 0xda, 0x26, 0x00, //@@@@@@@@@@@@@@+..%@@..
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0xae, 0xff, 0xff, 0xd4, 0x06, //@@@@@@@@@@@@@@+..%@@@.
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x0e, 0xc6, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@+...@@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x26, 0xff, 0xff, 0xa4, //@@@@@@@@@@@@@@+....@@%
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x10, 0xff, 0xff, 0xb2, //@@@@@@@@@@@@@@+....@@%
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x7c, 0xff, 0xff, 0x82, //@@@@@@@@@@@@@@+...+@@%
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x6c, 0xff, 0xff, 0xf8, 0x20, //@@@@@@@@@@@@@@+..+@@@.
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0xc8, 0xff, 0xff, 0x66, 0x00, //@@@@@@@@@@@@@@+..@@@+.
                0xf2, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x46, 0xac, 0x48, 0x00, 0x00, //@@@@@@@@@@@@@@+..+%+..
                0x46, 0x9c, 0x9e, 0x9e, 0x9e, 0x9e, 0x9e, 0xe0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //+%%%%%%@@@@@@@+.......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1e, 0xdc, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //........@@@@@@+.......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1e, 0xdc, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........@@@@@+.......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1e, 0xdc, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //..........@@@@+.......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1e, 0xdc, 0xff, 0xff, 0x7c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //...........@@@+.......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1e, 0xd2, 0xea, 0x32, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //............@@........
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
            };
            constexpr const AlphaSymbol symbol(width, height, data);
        }

        namespace high {
            constexpr const size_t height = 30;
            constexpr const size_t width = 31;
            constexpr const unsigned char data[height * width] = {
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x60, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //........................+........
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xa6, 0xff, 0xf6, 0x66, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.......................%@@+......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x8a, 0xff, 0xff, 0xff, 0x8a, 0x00, 0x00, 0x00, 0x00, 0x00, //.......................%@@@%.....
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x84, 0x9c, 0x12, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x8a, 0xff, 0xff, 0xff, 0x88, 0x00, 0x00, 0x00, 0x00, //............%%..........%@@@%....
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xaa, 0xff, 0xff, 0x72, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6a, 0xfc, 0xff, 0xff, 0x5a, 0x00, 0x00, 0x00, //...........%@@+..........+@@@+...
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xaa, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x50, 0xde, 0x8a, 0x02, 0x00, 0x00, 0x68, 0xff, 0xff, 0xf0, 0x1a, 0x00, 0x00, //..........%@@@+.....+@%...+@@@...
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xaa, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0xb4, 0xff, 0xff, 0xba, 0x10, 0x00, 0x00, 0xb0, 0xff, 0xff, 0xa6, 0x00, 0x00, //.........%@@@@+.....%@@%...%@@%..
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xa8, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x32, 0xf2, 0xff, 0xff, 0xbc, 0x02, 0x00, 0x14, 0xe6, 0xff, 0xfa, 0x16, 0x00, //........%@@@@@+......@@@%...@@@..
                0x08, 0x48, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0xaa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x34, 0xea, 0xff, 0xff, 0x78, 0x00, 0x00, 0x78, 0xff, 0xff, 0x76, 0x00, //.++++++%@@@@@@+.......@@@+..+@@+.
                0xc6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x12, 0x5a, 0x12, 0x00, 0x00, 0x2a, 0xf4, 0xff, 0xf8, 0x14, 0x00, 0x18, 0xfa, 0xff, 0xd8, 0x00, //@@@@@@@@@@@@@@+...+....@@@...@@@.
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0xb4, 0xff, 0xe2, 0x2c, 0x00, 0x00, 0x78, 0xff, 0xff, 0x72, 0x00, 0x00, 0xac, 0xff, 0xff, 0x2c, //@@@@@@@@@@@@@@+..%@@...+@@+..%@@.
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0xa6, 0xff, 0xff, 0xda, 0x08, 0x00, 0x10, 0xfa, 0xff, 0xd0, 0x00, 0x00, 0x6e, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@+..%@@@...@@@..+@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x0a, 0xbc, 0xff, 0xff, 0x64, 0x00, 0x00, 0xd2, 0xff, 0xf8, 0x00, 0x00, 0x4e, 0xff, 0xff, 0x84, //@@@@@@@@@@@@@@+...%@@+..@@@..+@@%
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x22, 0xff, 0xff, 0xa6, 0x00, 0x00, 0xa4, 0xff, 0xff, 0x1a, 0x00, 0x2c, 0xff, 0xff, 0x94, //@@@@@@@@@@@@@@+....@@%..%@@...@@%
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x12, 0xff, 0xff, 0xb0, 0x00, 0x00, 0x98, 0xff, 0xff, 0x22, 0x00, 0x20, 0xff, 0xff, 0x98, //@@@@@@@@@@@@@@+....@@%..%@@...@@%
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x86, 0xff, 0xff, 0x7e, 0x00, 0x00, 0xc6, 0xff, 0xfc, 0x04, 0x00, 0x38, 0xff, 0xff, 0x88, //@@@@@@@@@@@@@@+...%@@+..@@@...@@%
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x78, 0xff, 0xff, 0xf6, 0x1a, 0x00, 0x04, 0xf2, 0xff, 0xe0, 0x00, 0x00, 0x58, 0xff, 0xff, 0x6c, //@@@@@@@@@@@@@@+..+@@@...@@@..+@@+
                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0xc6, 0xff, 0xfc, 0x5a, 0x00, 0x00, 0x58, 0xff, 0xff, 0x90, 0x00, 0x00, 0x98, 0xff, 0xff, 0x3a, //@@@@@@@@@@@@@@+..@@@+..+@@%..%@@.
                0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x3a, 0x9c, 0x3a, 0x00, 0x00, 0x0e, 0xe0, 0xff, 0xff, 0x2a, 0x00, 0x02, 0xde, 0xff, 0xec, 0x06, //@@@@@@@@@@@@@@+...%....@@@...@@@.
                0x3c, 0x8c, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0xd6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x12, 0xc6, 0xff, 0xff, 0xac, 0x00, 0x00, 0x4e, 0xff, 0xff, 0x90, 0x00, //.%%%%%%@@@@@@@+.......@@@%..+@@%.
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0xd6, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14, 0xd4, 0xff, 0xff, 0xe2, 0x12, 0x00, 0x00, 0xc6, 0xff, 0xff, 0x2c, 0x00, //........@@@@@@+......@@@@...@@@..
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0xd6, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0xa0, 0xff, 0xff, 0xe8, 0x36, 0x00, 0x00, 0x68, 0xff, 0xff, 0xc6, 0x00, 0x00, //.........@@@@@+.....%@@@...+@@@..
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0xd6, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x88, 0xff, 0xc6, 0x1a, 0x00, 0x00, 0x2e, 0xf2, 0xff, 0xfc, 0x38, 0x00, 0x00, //..........@@@@+.....%@@....@@@...
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0xd6, 0xff, 0xff, 0x7a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x02, 0x00, 0x00, 0x20, 0xe6, 0xff, 0xff, 0x8c, 0x00, 0x00, 0x00, //...........@@@+...........@@@%...
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0xc8, 0xe0, 0x2c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0xe8, 0xff, 0xff, 0xbc, 0x04, 0x00, 0x00, 0x00, //............@@..........+@@@%....
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4a, 0xfa, 0xff, 0xff, 0xc2, 0x0c, 0x00, 0x00, 0x00, 0x00, //.......................+@@@@.....
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xb6, 0xff, 0xff, 0xa8, 0x0a, 0x00, 0x00, 0x00, 0x00, 0x00, //.......................%@@%......
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0xac, 0x62, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //........................%+.......
            };
            constexpr const AlphaSymbol symbol(width, height, data);
        }
    }

    namespace prev {
        constexpr const size_t height = 26;
        constexpr const size_t width = 16;
        constexpr const unsigned char data[height * width] = {
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //................
            0x38, 0x4e, 0x4e, 0x16, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x36, 0x1c, 0x00, //.++.............
            0xec, 0xff, 0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x98, 0xff, 0xf2, 0x22, //@@@%........%@@.
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xa6, 0xff, 0xff, 0xff, 0x5c, //@@@%.......%@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0xb2, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%......%@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%.....%@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x00, 0x10, 0xc8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%....@@@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x18, 0xd2, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%...@@@@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x1e, 0xda, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%..@@@@@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x26, 0xe2, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%.@@@@@@@@@@+
            0xee, 0xff, 0xff, 0xb0, 0xea, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%@@@@@@@@@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@@+
            0xee, 0xff, 0xff, 0xd6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x5e, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%+@@@@@@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x50, 0xf8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%.+@@@@@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x42, 0xf4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%..+@@@@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x00, 0x38, 0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%....@@@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x00, 0x00, 0x2c, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%.....@@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x00, 0x00, 0x00, 0x24, 0xde, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@%......@@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1a, 0xd6, 0xff, 0xff, 0xff, 0x5e, //@@@%.......@@@@+
            0xee, 0xff, 0xff, 0x82, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14, 0xcc, 0xff, 0xff, 0x3a, //@@@%........@@@.
            0x72, 0x8e, 0x8e, 0x34, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0x78, 0x52, 0x00, //+%%..........++.
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //................
        };
        constexpr const AlphaSymbol symbol(width, height, data);
    }

    namespace next {
        constexpr const size_t height = 26;
        constexpr const size_t width = 16;
        constexpr const unsigned char data[height * width] = {
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //................
            0x06, 0x40, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x42, 0x4e, 0x4e, 0x0c, //.+..........+++.
            0xac, 0xff, 0xe2, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xff, 0xff, 0xff, 0x5c, //%@@.........@@@+
            0xec, 0xff, 0xff, 0xea, 0x32, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@........@@@+
            0xee, 0xff, 0xff, 0xff, 0xf0, 0x3c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@@.......@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xf6, 0x4a, 0x00, 0x00, 0x00, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@@@+.....@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x58, 0x00, 0x00, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@+....@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x66, 0x00, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@+...@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x76, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@+..@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x86, 0x10, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@%.@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa4, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@@%@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xca, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb4, 0x18, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@%.@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa8, 0x04, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@%..@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9a, 0x02, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@%...@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x8c, 0x00, 0x00, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@%....@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@@@+.....@@@+
            0xee, 0xff, 0xff, 0xff, 0xff, 0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@@+......@@@+
            0xee, 0xff, 0xff, 0xfc, 0x62, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@@+.......@@@+
            0xce, 0xff, 0xfa, 0x54, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0e, 0xff, 0xff, 0xff, 0x5e, //@@@+........@@@+
            0x22, 0x84, 0x36, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x82, 0x8e, 0x8e, 0x22, //.%..........%%%.
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //................
        };
        constexpr const AlphaSymbol symbol(width, height, data);
    }

    namespace backward {
        constexpr const size_t height = 26;
        constexpr const size_t width = 25;
        constexpr const unsigned char data[height * width] = {
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x34, 0xac, 0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0x9c, 0x90, 0x08, //..........%+..........%%.
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x54, 0xf6, 0xff, 0xff, 0x26, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2c, 0xe0, 0xff, 0xff, 0x66, //........+@@@.........@@@+
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7a, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x48, 0xf0, 0xff, 0xff, 0xff, 0x7e, //.......+@@@@.......+@@@@+
            0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0xa0, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6a, 0xfc, 0xff, 0xff, 0xff, 0xff, 0x7e, //......%@@@@@......+@@@@@+
            0x00, 0x00, 0x00, 0x00, 0x12, 0xc0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x00, 0x00, 0x00, 0x02, 0x90, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //.....@@@@@@@.....%@@@@@@+
            0x00, 0x00, 0x00, 0x26, 0xda, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x00, 0x00, 0x0c, 0xb4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //....@@@@@@@@....%@@@@@@@+
            0x00, 0x00, 0x40, 0xec, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x00, 0x1c, 0xd0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //..+@@@@@@@@@...@@@@@@@@@+
            0x00, 0x60, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x34, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //.+@@@@@@@@@@..@@@@@@@@@@+
            0x76, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x80, 0xf4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //+@@@@@@@@@@@%@@@@@@@@@@@+
            0xf0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //@@@@@@@@@@@@@@@@@@@@@@@@+
            0xaa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xaa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //%@@@@@@@@@@@%@@@@@@@@@@@+
            0x06, 0xa0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x6a, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //.%@@@@@@@@@@.+@@@@@@@@@@+
            0x00, 0x00, 0x7a, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x00, 0x46, 0xf0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //..+@@@@@@@@@..+@@@@@@@@@+
            0x00, 0x00, 0x00, 0x56, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x00, 0x00, 0x2c, 0xe0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //...+@@@@@@@@....@@@@@@@@+
            0x00, 0x00, 0x00, 0x00, 0x36, 0xe8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x00, 0x00, 0x00, 0x16, 0xc8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //.....@@@@@@@.....@@@@@@@+
            0x00, 0x00, 0x00, 0x00, 0x00, 0x1e, 0xd2, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x00, 0x00, 0x00, 0x00, 0x08, 0xaa, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, //......@@@@@@......%@@@@@+
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0e, 0xb6, 0xff, 0xff, 0xff, 0xff, 0x3e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x84, 0xff, 0xff, 0xff, 0xff, 0x7e, //.......%@@@@.......%@@@@+
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x94, 0xff, 0xff, 0xff, 0x34, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x5e, 0xf8, 0xff, 0xff, 0x74, //........%@@@........+@@@+
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6a, 0xee, 0xb0, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3e, 0xe0, 0xd2, 0x1e, //.........+@%..........@@.
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
        };
        constexpr const AlphaSymbol symbol(width, height, data);
    }

    namespace forward {
        constexpr const size_t height = 26;
        constexpr const size_t width = 25;
        constexpr const unsigned char data[height * width] = {
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x4a, 0xb0, 0x58, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x24, 0xac, 0x7e, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //+%+..........%+..........
            0xea, 0xff, 0xff, 0x88, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xaa, 0xff, 0xff, 0xbc, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@%........%@@%.........
            0xff, 0xff, 0xff, 0xff, 0xae, 0x0a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xd6, 0x22, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@%.......%@@@@........
            0xff, 0xff, 0xff, 0xff, 0xff, 0xcc, 0x18, 0x00, 0x00, 0x00, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xea, 0x3a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@......%@@@@@.......
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe2, 0x2e, 0x00, 0x00, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x5a, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@.....%@@@@@@+.....
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf2, 0x4c, 0x00, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@+...%@@@@@@@+....
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x6e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa4, 0x06, 0x00, 0x00, //@@@@@@@@@+..%@@@@@@@@%...
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x96, 0x02, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc4, 0x14, 0x00, //@@@@@@@@@@%.%@@@@@@@@@@..
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb2, 0xc2, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdc, 0x18, //@@@@@@@@@@@%@@@@@@@@@@@@.
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x70, //@@@@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xde, 0xcc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x32, //@@@@@@@@@@@@@@@@@@@@@@@@.
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xcc, 0x18, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xea, 0x3a, 0x00, //@@@@@@@@@@@.%@@@@@@@@@@..
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xae, 0x0a, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd6, 0x22, 0x00, 0x00, //@@@@@@@@@%..%@@@@@@@@@...
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x88, 0x00, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xba, 0x10, 0x00, 0x00, 0x00, //@@@@@@@@%...%@@@@@@@%....
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x64, 0x00, 0x00, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9a, 0x04, 0x00, 0x00, 0x00, 0x00, //@@@@@@@+....%@@@@@@%.....
            0xff, 0xff, 0xff, 0xff, 0xff, 0xee, 0x42, 0x00, 0x00, 0x00, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x72, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@+.....%@@@@@+......
            0xff, 0xff, 0xff, 0xff, 0xdc, 0x26, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xf4, 0x4e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@.......%@@@@+.......
            0xf6, 0xff, 0xff, 0xc2, 0x14, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xb6, 0xff, 0xff, 0xe4, 0x32, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@........%@@@.........
            0x82, 0xf4, 0x98, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4c, 0xec, 0xc0, 0x1a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //%@%.........+@@..........
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.........................
        };
        constexpr const AlphaSymbol symbol(width, height, data);
    }

    namespace play {
        constexpr const size_t height = 26;
        constexpr const size_t width = 22;
        constexpr const unsigned char data[height * width] = {
            0x16, 0xa2, 0xc8, 0x78, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.%@+..................
            0xbe, 0xff, 0xff, 0xff, 0xdc, 0x4a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //%@@@@+................
            0xf8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb0, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@%...............
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0x7a, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@+.............
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xda, 0x46, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@@@+...........
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xac, 0x1c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@@@@%..........
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf4, 0x78, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@@@@@@+........
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd8, 0x44, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@@@@@@@@+......
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa8, 0x1a, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@@@@@@@@@%.....
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf2, 0x74, 0x04, 0x00, 0x00, //@@@@@@@@@@@@@@@@@@+...
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd4, 0x34, 0x00, //@@@@@@@@@@@@@@@@@@@@..
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf2, 0x1e, //@@@@@@@@@@@@@@@@@@@@@.
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x34, //@@@@@@@@@@@@@@@@@@@@@.
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0x68, 0x00, //@@@@@@@@@@@@@@@@@@@@+.
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb4, 0x22, 0x00, 0x00, //@@@@@@@@@@@@@@@@@@%...
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x4e, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@@@@@@@@@@+....
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x84, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@@@@@@@@%......
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb8, 0x24, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@@@@@@%........
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe2, 0x52, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@@@@@+.........
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x88, 0x0a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@@@%...........
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbc, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@@%.............
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe4, 0x56, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@@@+..............
            0xd4, 0xff, 0xff, 0xff, 0xfa, 0x8a, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //@@@@@%................
            0x3c, 0xe8, 0xfc, 0xb8, 0x2a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //.@@%..................
            0x00, 0x02, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
        };
        constexpr const AlphaSymbol symbol(width, height, data);
    }

    namespace pause {
        constexpr const size_t height = 26;
        constexpr const size_t width = 22;
        constexpr const unsigned char data[height * width] = {
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
            0x00, 0x2a, 0x58, 0x5a, 0x5a, 0x5a, 0x5a, 0x38, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1a, 0x54, 0x5a, 0x5a, 0x5a, 0x5a, 0x48, 0x06, 0x00, //..+++++.......++++++..
            0x68, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x94, 0x00, 0x00, 0x00, 0x34, 0xf2, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xcc, 0x06, //+@@@@@@@%....@@@@@@@@.
            0xea, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x16, 0x00, 0x00, 0xaa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x56, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2e, 0x00, 0x00, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@...%@@@@@@@@+
            0xf0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x1e, 0x00, 0x00, 0xb0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5e, //@@@@@@@@@...%@@@@@@@@+
            0x8c, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb8, 0x00, 0x00, 0x00, 0x4e, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe4, 0x12, //%@@@@@@@%...+@@@@@@@@.
            0x00, 0x54, 0x82, 0x82, 0x82, 0x82, 0x82, 0x62, 0x06, 0x00, 0x00, 0x00, 0x00, 0x38, 0x7c, 0x82, 0x82, 0x82, 0x82, 0x72, 0x18, 0x00, //.+%%%%%+......+%%%%+..
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
        };
        constexpr const AlphaSymbol symbol(width, height, data);
    }

    namespace stop {
        constexpr const size_t height = 26;
        constexpr const size_t width = 22;
        constexpr const unsigned char data[height * width] = {
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
            0x00, 0x20, 0x4c, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x4e, 0x3c, 0x02, 0x00, //..+++++++++++++++++...
            0x60, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc2, 0x04, //+@@@@@@@@@@@@@@@@@@@@.
            0xe6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x54, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6e, //@@@@@@@@@@@@@@@@@@@@@+
            0xf2, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x60, //@@@@@@@@@@@@@@@@@@@@@+
            0x94, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xea, 0x16, //%@@@@@@@@@@@@@@@@@@@@.
            0x02, 0x60, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x8e, 0x7e, 0x1e, 0x00, //.+%%%%%%%%%%%%%%%%%+..
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //......................
        };
        constexpr const AlphaSymbol symbol(width, height, data);
    }
}
